pub struct ListTypesResponse {
pub next_token: Option<String>,
pub types: Option<Vec<Type>>,
}Fields
next_token: Option<String>An identifier to be passed in the next request to this operation to return the next set of items in the list.
types: Option<Vec<Type>>The Type objects.